# Copyright 2000 by Brad Chapman.  All rights reserved.
# This code is part of the Biopython distribution and governed by its
# license.  Please see the LICENSE file that should have been included
# as part of this package.

# stubs generated from the idl
import BioCorba.org__POA.biocorba.seqcore as seqcore__POA
import BioCorba.org.biocorba.seqcore as seqcore

# classes we will be returning instances of
from CorbaPrimarySeq import CorbaPrimarySeq
from Vector import CorbaRestrictedSeqFeatureVector

class CorbaSeq(seqcore__POA.Seq, CorbaPrimarySeq):
    """Seq BioCorba implementation.

    This class inherits from:
    * org__POA.biocorba.seqcore.Seq - The corba stub code
    implementing code for connecting through corba (this is
    generated by the orb implementation.)
    * CorbaPrimarySeq - The basic sequence class (without features) from
    which this derives in the idl.
    """
    def __init__(self, seq_record):
        CorbaPrimarySeq.__init__(self, seq_record)

    def all_SeqFeatures(self, use_subfeatures = 1):
        """Retrieve a Vector of SeqFeature objects.
        """
        seqfeat_vector = \
          CorbaRestrictedSeqFeatureVector(self._seq_record.features, 1,
                                          use_subfeatures)
        return seqfeat_vector.get_object()
    
    def get_SeqFeatures_by_type(self, use_subfeatures = 1, type = 'exon'):
        """Retrieve a Vector of SeqFeature objects of a specified type.
        """
        seqfeat_vector = \
          CorbaRestrictedSeqFeatureVector(self._seq_record.features, 1,
                                          use_subfeatures, None, None, type)
        return seqfeat_vector.get_object()
                                                  
    def get_SeqFeatures_in_region(self, start, end, use_subfeatures = 1):
        """Retrieve a Vector of SeqFeature objects in a region.
        """
        seqfeat_vector = \
          CorbaRestrictedSeqFeatureVector(self._seq_record.features, 1,
                                          use_subfeatures, start, end)
        return seqfeat_vector.get_object()

    def get_SeqFeatures_in_region_by_type(self, start, end,
                                          use_subfeatures = 1, type = 'exon'):
        """Retrieve a vector of SeqFeatures restricted by type and region.
        """
        seqfeat_vector = \
          CorbaRestrictedSeqFeatureVector(self._seq_record.features, 1,
                                          use_subfeatures, start, end, type)
        return seqfeat_vector.get_object()

    def get_PrimarySeq(self):
        """Return a PrimarySeq object corresponding to this sequence.
        """
        p_seq = CorbaPrimarySeq(self._seq_record)
        return p_seq.get_object()
